The hardware and bandwidth for this mirror is donated by dogado GmbH, the Webhosting and Full Service-Cloud Provider. Check out our Wordpress Tutorial.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]dogado.de.

Title: Fast Reverse Complement of DNA and RNA Sequences
Version: 0.0.2
Description: Fast reverse complement of DNA and RNA sequences using a 'C++' lookup table for O(1) per-base complement mapping. Supports full IUPAC ambiguity codes, DNA and RNA modes, case preservation, and NA handling. Much faster than other packages for computing reverse complements of many short sequences such as primers, probes, and, k-mers.
License: GPL (≥ 3)
Language: en-US
Encoding: UTF-8
RoxygenNote: 7.3.3
Suggests: testthat (≥ 3.0.0)
Config/testthat/edition: 3
LinkingTo: Rcpp
Imports: Rcpp
NeedsCompilation: yes
Packaged: 2026-02-24 20:48:02 UTC; steve
Author: Steven G. Rozen [aut, cre]
Maintainer: Steven G. Rozen <steverozen@pm.me>
Repository: CRAN
Date/Publication: 2026-03-03 10:10:07 UTC

fastrc: Fast Reverse Complement of DNA and RNA Sequences

Description

Fast reverse complement of DNA and RNA sequences using a 'C++' lookup table for O(1) per-base complement mapping. Supports full IUPAC ambiguity codes, DNA and RNA modes, case preservation, and NA handling. Much faster than other packages for computing reverse complements of many short sequences such as primers, probes, and, k-mers.

Author(s)

Maintainer: Steven G. Rozen steverozen@pm.me


Fast Reverse Complement of DNA/RNA Sequences

Description

Computes the reverse complement of one or more DNA or RNA sequences using a C++ lookup table for O(1) complement mapping. Supports full IUPAC ambiguity codes and preserves case.

Usage

fast_rc(seqs, type = "DNA")

Arguments

seqs

A character vector of DNA or RNA sequences.

type

Either "DNA" (A\leftrightarrowT) or "RNA" (A\leftrightarrowU).

Value

A character vector of reverse-complemented sequences, with NA values preserved.

Examples

fast_rc("ATCG")
fast_rc(c("ATCG", "AAGG", NA))
fast_rc("AUCG", type = "RNA")

These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.
Health stats visible at Monitor.